
local addonName, addon = ...

local L = LibStub("AceLocale-3.0"):GetLocale(addonName, true)

addon.filters["Item Stat Filter"] = {}
local filter = addon.filters["Item Stat Filter"]

filter.itemstat ={}
filter.itemstat_filtered ={}
filter.itemstatChecked = false

local order = {}
local TypeSelect = {
	type = 'toggle',
	desc = L['When selected this item stat will be filtered out'],
	name = function(info)	
		return _G[info[#info]]
	end,
	get = function(info)
		return addon.db.profile.ItemStatFilter[info[#info]]
	end,
	set = function(info, val)
		addon.db.profile.ItemStatFilter[info[#info]] = val
	end,
	order = function(info)
		return order[info[#info]]+1
	end,
}

local itemtypesorted, itemtypesortedL = {}, {}
function filter:UpdateOptions()
	wipe(itemtypesorted)
	if not addon.filterOptions["Item Stat Filter"] then
		addon.filterOptions["Item Stat Filter"] = {
			type = 'group',
			name = L["Item Stat Filter"],
			args = {
				desc = {
					type = 'description',
					name = L['Only item stats you have previously seen can be filtered by default'],
					order = 1,
				},
			},
		}
		local args = addon.filterOptions["Item Stat Filter"].args
		
		for l in pairs(addon.db.global.ItemStatFilter) do
			local Lo = _G[l]
			if Lo then
				itemtypesorted[#itemtypesorted+1] = Lo
				itemtypesortedL[Lo] = l
			end
		end
		table.sort(itemtypesorted)
		wipe(order)
		for i, l in ipairs(itemtypesorted) do
			order[itemtypesortedL[l]] = i
		end
		
		for Lo, l in pairs(itemtypesortedL) do
			args[l] = TypeSelect
		end
	end
end

local tempStats = {}
function filter:AddItem(link)
	wipe(tempStats)
	GetItemStats(link, tempStats)
	for stat in pairs(tempStats) do
		if _G[stat] then
			self.itemstat[stat] = true
		end
		addon.db.global.ItemStatFilter[stat] = true
	end
end

function filter:ClearAll()
	wipe(self.itemstat)
	filter:ResetFilter()
end

function filter:isFilterd(link)
	wipe(tempStats)
	GetItemStats(link, tempStats)
	for stat in pairs(tempStats) do
		if self.itemstat_filtered[stat] then
			return true
		end
	end
	return false
end

function filter:ResetFilter()
	wipe(self.itemstat_filtered)
	for q, v in pairs(addon.db.profile.ItemStatFilter) do
		self.itemstat_filtered[q] = v
	end
end

function filter:ShowAll()
	wipe(self.itemstat_filtered)
end

function filter:FilterAll()
	if self:isRelevant() then
		for i in pairs(addon.db.global.ItemStatFilter) do
			self.itemstat_filtered[i] = true
		end
	end
end

function filter:isRelevant()
	local count = 0
	for k in pairs(self.itemstat) do
		count = count + 1
		if count > 1 then
			return true
		end
	end
	return false
end

function filter:WriteDefault(db)
	db.profile.ItemStatFilter = {}
	db.global.ItemStatFilter = {}
end

local info = {}
function filter:GetDropdown(level)
	wipe(info)
	wipe(itemtypesorted)
	info.keepShownOnClick = 1
    if level == 1 then
		info.text = STATS_LABEL
		info.value = STATS_LABEL
		info.hasArrow = true
		info.func = function()
			local b = not self.itemstatChecked
			self.itemstatChecked = b
			for el in pairs(self.itemstat) do
				self.itemstat_filtered[el] = b
			end
			ToggleDropDownMenu(1, nil, addon.FilterMenu, addon.FilterButton, 0, 0)
			ToggleDropDownMenu(1, nil, addon.FilterMenu, addon.FilterButton, 0, 0)
			addon:FilterUpdate()
		end
		UIDropDownMenu_AddButton(info, level)
	elseif level == 2 and STATS_LABEL == UIDROPDOWNMENU_MENU_VALUE then
		for l in pairs(self.itemstat) do
			local L = _G[l]
			if L then
				itemtypesorted[#itemtypesorted+1] = L
				itemtypesortedL[L] = l
			end
		end
		table.sort(itemtypesorted)

		for i = 1, #itemtypesorted do
			info.text = itemtypesorted[i]
			info.arg1 = itemtypesortedL[itemtypesorted[i]]
			info.checked = not self.itemstat_filtered[itemtypesortedL[itemtypesorted[i]]]
			info.func = function(button, arg1)
				self.itemstat_filtered[arg1] = not self.itemstat_filtered[arg1]
				addon:FilterUpdate()
			end
			UIDropDownMenu_AddButton(info, level)
		end
	end
end